@@ -31,6 +31,7 @@ use tracing_futures::Instrument;
 /// use krator::admission;
 /// use krator_derive::AdmissionWebhook;
 /// use kube::{Api, Client};
+/// use kube::CustomResourceExt;
 /// use kube_derive::CustomResource;
 /// use schemars::JsonSchema;
 /// use serde::{Deserialize, Serialize};
@@ -182,7 +183,7 @@ impl WebhookResources {
             let api: kube::Api<Secret> = kube::Api::namespaced(client.to_owned(), secret_namespace);
             let name = self.secret().metadata.name.as_ref().unwrap();
             api.patch(
-                &name,
+                name,
                 &PatchParams {
                     dry_run: false,
                     force: true,
@@ -198,7 +199,7 @@ impl WebhookResources {
                 kube::Api::namespaced(client.to_owned(), service_namespace);
             let name = self.service().metadata.name.as_ref().unwrap();
             api.patch(
-                &name,
+                name,
                 &PatchParams {
                     dry_run: false,
                     force: true,
@@ -213,7 +214,7 @@ impl WebhookResources {
             let api: kube::Api<MutatingWebhookConfiguration> = kube::Api::all(client.to_owned());
             let name = self.webhook_config().metadata.name.as_ref().unwrap();
             api.patch(
-                &name,
+                name,
                 &PatchParams {
                     dry_run: false,
                     force: true,
@@ -261,7 +262,7 @@ impl Display for WebhookResources {
 }
 
 /// AdmissionTls wraps certificate and private key for the admission webhook server. If you read
-/// the secret from a Kubernets secret, use the convenience function [AdmissionTls::from()]
+/// the secret from a Kubernetes secret, use the convenience function [AdmissionTls::from()]
 pub struct AdmissionTls {
     /// tls certificate
     pub cert: String,
